Aligner
=======

.. currentmodule:: bioregistry.align

.. autoclass:: Aligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Aligner.alt_key_match
      ~Aligner.getter_kwargs
      ~Aligner.include_new
      ~Aligner.internal_registry
      ~Aligner.skip_deprecated
      ~Aligner.subkey

   .. rubric:: Methods Summary

   .. autosummary::

      ~Aligner.align
      ~Aligner.cli
      ~Aligner.get_curation_row
      ~Aligner.get_curation_table
      ~Aligner.get_skip
      ~Aligner.prepare_external
      ~Aligner.print_curation_table
      ~Aligner.write_curation_table
      ~Aligner.write_registry

   .. rubric:: Attributes Documentation

   .. autoattribute:: alt_key_match
   .. autoattribute:: getter_kwargs
   .. autoattribute:: include_new
   .. autoattribute:: internal_registry
   .. autoattribute:: skip_deprecated
   .. autoattribute:: subkey

   .. rubric:: Methods Documentation

   .. automethod:: align
   .. automethod:: cli
   .. automethod:: get_curation_row
   .. automethod:: get_curation_table
   .. automethod:: get_skip
   .. automethod:: prepare_external
   .. automethod:: print_curation_table
   .. automethod:: write_curation_table
   .. automethod:: write_registry
